<?php

namespace Drupal\noahs_page_builder\Service;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;

class WidgetServices
{

    protected $widgetManager;
    protected $controlManager;
  
    public function __construct(DefaultPluginManager $widget_manager, $control_manager) {
      $this->widgetManager = $widget_manager;
      $this->controlManager = $control_manager;
    }
  
    public static function create(ContainerInterface $container) {
      return new static(
        $container->get('plugin.manager.widget'),
        $container->get('plugin.manager.control')
      );
    }
    /** 
     * Get widget list. 
     * 
     */
    public function getWidgetsList(){
        $data = [];
        $widgets = [];
        // Obtén todos los plugins de tipo widget.

        foreach ($this->widgetManager->getDefinitions() as $plugin_id => $plugin_definition) {
            $widget = $this->widgetManager->createInstance($plugin_id);


            $widget_data = $widget->data();
            if ($plugin_id !== 'noahs_column') {
                $data[$plugin_id] = $widget->data();
            }
        }
  
        $groupedArray = [];
        foreach ($data as $key => $value) {
            $group = $value['group'] ?? 'default';
            $groupedArray[$group][$key] = $value;
        }

        return $groupedArray;
    }

    /** 
     * Get widget. 
     * 
     */
    public function loadWidgetById($widget_id) {
        if ($this->widgetManager->hasDefinition($widget_id)) {
          $widget = $this->widgetManager->createInstance($widget_id);
          return $widget;
        }
        
        return NULL;
    }

    /**
     * Get widgets fields
     */
    public function getWidgetFields($widgetId){
        $el_fields = array();

        $default_fields = $this->controlManager->defaultFields();

        $widget =  $this->loadWidgetById($widgetId);
        $route_match = \Drupal::routeMatch();
        if($widget){
            $el_fields = $widget->renderForm();
            $el_fields = array_merge($el_fields, $default_fields);

            return $el_fields;
        }
    }

    /**
     * Get widgets data
     */
    public function getWidgetData($widgetId){
        if ($this->widgetManager->hasDefinition($widgetId)) {
            $widget = $this->widgetManager->createInstance($widgetId);
            return $widget->data();
        }
    }
}
